==> jc-1.4.0.tar.gz: org/w3c/dom/events/EventException.h <==
// public class org.w3c.dom.events.EventException

// class file dependencies
// @dep_class c5feb325780a6cd7 java_lang_Exception
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 4f5534a987354d1d java_lang_RuntimeException
// @dep_class 3be5c3c4fdd59a1e java_lang_Throwable
// @dep_class 25bca8504e3fdf15 org_w3c_dom_events_EventException

// header file dependencies
// @dep_header java_lang_RuntimeException

#include "java/lang/RuntimeException.h"

#ifndef _JC_org_w3c_dom_events_EventException_H_
#define _JC_org_w3c_dom_events_EventException_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_org_w3c_dom_events_EventException$sub_refs	_jc_org_w3c_dom_events_EventException$sub_refs;
typedef struct _jc_org_w3c_dom_events_EventException$sub_nonrefs	_jc_org_w3c_dom_events_EventException$sub_nonrefs;
typedef struct _jc_org_w3c_dom_events_EventException$refs	_jc_org_w3c_dom_events_EventException$refs;
typedef struct _jc_org_w3c_dom_events_EventException$nonrefs	_jc_org_w3c_dom_events_EventException$nonrefs;
typedef struct _jc_org_w3c_dom_events_EventException$object	_jc_org_w3c_dom_events_EventException$object;

typedef struct _jc_org_w3c_dom_events_EventException$fields_struct	_jc_org_w3c_dom_events_EventException$fields_struct;
typedef const struct _jc_org_w3c_dom_events_EventException$vmethods	_jc_org_w3c_dom_events_EventException$vmethods;
typedef const struct _jc_org_w3c_dom_events_EventException$vtable	_jc_org_w3c_dom_events_EventException$vtable;
typedef const struct _jc_org_w3c_dom_events_EventException$vtype	_jc_org_w3c_dom_events_EventException$vtype;

// Class fields structure
struct _jc_org_w3c_dom_events_EventException$fields_struct {
	jshort	UNSPECIFIED__5fEVENT__5fTYPE__5fERR;
};
extern _jc_org_w3c_dom_events_EventException$fields_struct _jc_org_w3c_dom_events_EventException$class_fields;

// Constructors
extern void _jc_org_w3c_dom_events_EventException$method$_init$f5cdf9de5128930c(_jc_env *, struct _jc_org_w3c_dom_events_EventException$object *, jshort, struct _jc_java_lang_String$object *);

// Virtual methods structure
struct _jc_org_w3c_dom_events_EventException$vmethods {
};

// Vtable
struct _jc_org_w3c_dom_events_EventException$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_lang_Throwable$vmethods	java_lang_Throwable;
	_jc_java_lang_Exception$vmethods	java_lang_Exception;
	_jc_java_lang_RuntimeException$vmethods	java_lang_RuntimeException;
	_jc_org_w3c_dom_events_EventException$vmethods	org_w3c_dom_events_EventException;
};

// Vtype
struct _jc_org_w3c_dom_events_EventException$vtype {
	_jc_type			type;
	_jc_org_w3c_dom_events_EventException$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_org_w3c_dom_events_EventException$sub_refs {
};

// Reference instance fields (object)
struct _jc_org_w3c_dom_events_EventException$refs {
    _jc_org_w3c_dom_events_EventException$sub_refs	org_w3c_dom_events_EventException;
    _jc_java_lang_RuntimeException$sub_refs	java_lang_RuntimeException;
    _jc_java_lang_Exception$sub_refs	java_lang_Exception;
    _jc_java_lang_Throwable$sub_refs	java_lang_Throwable;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_org_w3c_dom_events_EventException$sub_nonrefs {
	jshort	code;
};

// Non-reference instance fields (object)
struct _jc_org_w3c_dom_events_EventException$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_lang_Throwable$sub_nonrefs	java_lang_Throwable;
    _jc_java_lang_Exception$sub_nonrefs	java_lang_Exception;
    _jc_java_lang_RuntimeException$sub_nonrefs	java_lang_RuntimeException;
    _jc_org_w3c_dom_events_EventException$sub_nonrefs	org_w3c_dom_events_EventException;
};

// Object instance structure
struct _jc_org_w3c_dom_events_EventException$object {
	_jc_org_w3c_dom_events_EventException$refs	refs[0];
	_jc_word		lockword;
	_jc_org_w3c_dom_events_EventException$vtype	*vtype;
	_jc_org_w3c_dom_events_EventException$nonrefs	nonrefs;
};

// Type structure
extern _jc_org_w3c_dom_events_EventException$vtype _jc_org_w3c_dom_events_EventException$type;

// Array types class info structures
_JC_DECL_ARRAYS(org_w3c_dom_events_EventException, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_org_w3c_dom_events_EventException$class_object;

#endif	/* _JC_org_w3c_dom_events_EventException_H_ */

==> jc-1.4.6.tar.gz: org/w3c/dom/events/EventException.h <==
// public class org.w3c.dom.events.EventException

// class file dependencies
// @dep_class c5feb325780a6cd7 java_lang_Exception
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 4f5534a987354d1d java_lang_RuntimeException
// @dep_class 3be5c3c4fdd59a1e java_lang_Throwable
// @dep_class 25bca8504e3fdf15 org_w3c_dom_events_EventException

// header file dependencies
// @dep_header java_lang_RuntimeException

#include "java/lang/RuntimeException.h"

#ifndef _JC_org_w3c_dom_events_EventException_H_
#define _JC_org_w3c_dom_events_EventException_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_org_w3c_dom_events_EventException$sub_refs	_jc_org_w3c_dom_events_EventException$sub_refs;
typedef struct _jc_org_w3c_dom_events_EventException$sub_nonrefs	_jc_org_w3c_dom_events_EventException$sub_nonrefs;
typedef struct _jc_org_w3c_dom_events_EventException$refs	_jc_org_w3c_dom_events_EventException$refs;
typedef struct _jc_org_w3c_dom_events_EventException$nonrefs	_jc_org_w3c_dom_events_EventException$nonrefs;
typedef struct _jc_org_w3c_dom_events_EventException$object	_jc_org_w3c_dom_events_EventException$object;

typedef struct _jc_org_w3c_dom_events_EventException$fields_struct	_jc_org_w3c_dom_events_EventException$fields_struct;
typedef const struct _jc_org_w3c_dom_events_EventException$vmethods	_jc_org_w3c_dom_events_EventException$vmethods;
typedef const struct _jc_org_w3c_dom_events_EventException$vtable	_jc_org_w3c_dom_events_EventException$vtable;
typedef const struct _jc_org_w3c_dom_events_EventException$vtype	_jc_org_w3c_dom_events_EventException$vtype;

// Class fields structure
struct _jc_org_w3c_dom_events_EventException$fields_struct {
	jshort	UNSPECIFIED__5fEVENT__5fTYPE__5fERR;
};
extern _jc_org_w3c_dom_events_EventException$fields_struct _jc_org_w3c_dom_events_EventException$class_fields;

// Constructors
extern void _jc_org_w3c_dom_events_EventException$method$_init$f5cdf9de5128930c(_jc_env *, struct _jc_org_w3c_dom_events_EventException$object *, jshort, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_org_w3c_dom_events_EventException$vmethods {
};

// Vtable
struct _jc_org_w3c_dom_events_EventException$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_lang_Throwable$vmethods	java_lang_Throwable;
	_jc_java_lang_Exception$vmethods	java_lang_Exception;
	_jc_java_lang_RuntimeException$vmethods	java_lang_RuntimeException;
	_jc_org_w3c_dom_events_EventException$vmethods	org_w3c_dom_events_EventException;
};

// Vtype
struct _jc_org_w3c_dom_events_EventException$vtype {
	_jc_type			type;
	_jc_org_w3c_dom_events_EventException$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_org_w3c_dom_events_EventException$sub_refs {
};

// Reference instance fields (object)
struct _jc_org_w3c_dom_events_EventException$refs {
    _jc_org_w3c_dom_events_EventException$sub_refs	org_w3c_dom_events_EventException;
    _jc_java_lang_RuntimeException$sub_refs	java_lang_RuntimeException;
    _jc_java_lang_Exception$sub_refs	java_lang_Exception;
    _jc_java_lang_Throwable$sub_refs	java_lang_Throwable;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_org_w3c_dom_events_EventException$sub_nonrefs {
	jshort	code;
};

// Non-reference instance fields (object)
struct _jc_org_w3c_dom_events_EventException$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_lang_Throwable$sub_nonrefs	java_lang_Throwable;
    _jc_java_lang_Exception$sub_nonrefs	java_lang_Exception;
    _jc_java_lang_RuntimeException$sub_nonrefs	java_lang_RuntimeException;
    _jc_org_w3c_dom_events_EventException$sub_nonrefs	org_w3c_dom_events_EventException;
};

// Object instance structure
struct _jc_org_w3c_dom_events_EventException$object {
	_jc_org_w3c_dom_events_EventException$refs	refs[0];
	_jc_word		lockword;
	_jc_org_w3c_dom_events_EventException$vtype	*vtype;
	_jc_org_w3c_dom_events_EventException$nonrefs	nonrefs;
};

// Type structure
extern _jc_org_w3c_dom_events_EventException$vtype _jc_org_w3c_dom_events_EventException$type;

// Array types class info structures
_JC_DECL_ARRAYS(org_w3c_dom_events_EventException, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_org_w3c_dom_events_EventException$class_object;

#endif	/* _JC_org_w3c_dom_events_EventException_H_ */
